#ifndef __DIGIDOC_MEM_H__
#define __DIGIDOC_MEM_H__
//==================================================
// FILE:	DigiDocMem.h
// PROJECT:     Digi Doc
// DESCRIPTION: Digi Doc functions for memory buffer management
// AUTHOR:  Veiko Sinivee, S|E|B IT Partner Estonia
//==================================================
// Copyright (C) AS Sertifitseerimiskeskus
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// GNU Lesser General Public Licence is available at
// http://www.gnu.org/copyleft/lesser.html
//==========< HISTORY >=============================
//      09.09.2004      Veiko Sinivee
//                      Creation
//==================================================

#ifdef  __cplusplus
extern "C" {
#endif

  typedef struct DigiDocMemBuf_st {
    void* pMem; // functions will assign allocated memory address here
    int nLen;   // length of data in number of bytes
  } DigiDocMemBuf;

  //--------------------------------------------------
  // Helper function to append data to a memory buffer
  // and grow it as required.
  // pBuf - address of memory buffer pointer
  // data - new data to be appended
  // len - length of data or -1 for zero terminated strings
  //--------------------------------------------------
  int ddocMemAppendData(DigiDocMemBuf* pBuf, const char* data, int len);

  //--------------------------------------------------
  // Helper function to assign data to a memory buffer
  // and release old content if necessary
  // pBuf - address of memory buffer pointer
  // data - new data to be appended
  // len - length of data or -1 for zero terminated strings
  //--------------------------------------------------
  int ddocMemAssignData(DigiDocMemBuf* pBuf, const char* data, int len);


#ifdef  __cplusplus
}
#endif

#endif // __DIGIDOC_MEM_H__
